DesignElement class
Constructors
- DesignElement({required String id, required ElementType type, required double x, required double y, required double width, required double height, TextWidget? textWidget, String? imageUrl})
-
DesignElement.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → RxDouble
-
final
- id → String
-
final
- imageUrl → RxString?
-
final
- isActive → RxBool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
textWidget
→ Rx<
TextWidget?> -
final
-
type
→ Rx<
ElementType> -
final
- width → RxDouble
-
final
- x → RxDouble
-
final
- y → RxDouble
-
final
Methods
-
dispose(
) → void - Clean up all Rx observables when the element is no longer needed
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited